Documentation
=============

.. note::

    We suppose that you already followed the :doc:`/installation` guide. If not, please do so
    before you continue to read this section.

To locally generate and preview documentation run the following command in the project root folder:

.. code-block:: bash

    pipenv run sphinx-autobuild docs/source docs/build/html

If the build of the documentation is successful, you can preview the documentation by navigating to the http://127.0.0.1:8000.

